@@ -30,7 +30,7 @@
 SegatexAlertAudit::SegatexAlertAudit(QWidget *parent, const char *name): QDialog(parent, name)
 {
                 setCaption(tr("segatex alert audit"));
-                alertLabel = new QLabel(tr("AVC Denied !"), this );
+                alertLabel = new QLabel(tr("Denied message in audit.log !"), this );
                 mainLayout = new QHBoxLayout(this);
                 mainLayout->setMargin(11);
                 mainLayout->setSpacing(6);
