@@ -35,16 +35,8 @@
 #include <qtextedit.h>
 
 #include "editor.h"
-#include "parselines.h"
-#include "parselines_admin.h"
-#include "parselines_apps.h"
-#include "parselines_kernel.h"
-#include "parselines_services.h"
-#include "parselines_system.h"
-#include "parselines_misc.h"
-#include "parselines_selpaw.h"
-#include "selpaw.h"
-#include "selpaw_adjust.h"
+
+#include "breakte.h"
 #include "segatex_state.h"
 #include "segatex_apply.h"
 #include "segatex_setenforce.h"
@@ -78,22 +70,10 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	//declare workspace as a child of horizontalSplitter
 	workspace = new QWorkspace(horizontalSplitter);
 
-	parse1 = new ParseLinesAdmin();
-	parse2 = new ParseLinesApps();
-	parse3 = new ParseLinesKernel();
-	parse4 = new ParseLinesServices();
-	parse5 = new ParseLinesSystem();
-	parse6 = new ParseLinesMisc();
-	parse9 = new ParseLinesAdmin();
-	parse10 = new ParseLinesApps();
-	parse11 = new ParseLinesKernel();
-	parse12 = new ParseLinesServices();
-	parse13 = new ParseLinesSystem();    
-	parse14 = new ParseLinesSelpaw();
-	selpaw1 = new Selpaw();
-	selpawadjust1 = new SelpawAdjust();
+	breakte = new BreakTe();
 	segatex_state = new SegatexState();
 	//needs here to be declared when opening a new window unless segmentation fualt happens...
+	breakte_o = 0;
 	segatex_apply = 0;
 	selinux_yum = 0;
 	selinux_yum_process = 0;
@@ -129,7 +109,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex-6.60"));
+	setCaption(tr("segatex-6.80"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -239,151 +219,11 @@ void MainWindow::createActions()
 	connect(aboutQtAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
 	//newly added-1:create action
-	parse_adminAct = new QAction(tr("Parse &Admin"), 0, this);
-	parse_adminAct->setStatusTip(tr("Parse .if files in admin layer"));
-	connect(parse_adminAct, SIGNAL(activated()), parse1, SLOT(parse_admin()));
-	connect(parse_adminAct, SIGNAL(activated()), this, SLOT(open_interfaces_admin_txt()));
-	connect(parse_adminAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	parse_appsAct = new QAction(tr("Parse A&pps"), 0, this);
-	parse_appsAct->setStatusTip(tr("Parse .if files in apps layer"));
-	connect(parse_appsAct, SIGNAL(activated()), parse2, SLOT(parse_apps()));
-	connect(parse_appsAct, SIGNAL(activated()), this, SLOT(open_interfaces_apps_txt()));
-	connect(parse_appsAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	parse_kernelAct = new QAction(tr("Parse &Kernel"), 0, this);
-	parse_kernelAct->setStatusTip(tr("Parse .if files in kernel layer"));
-	connect(parse_kernelAct, SIGNAL(activated()), parse3, SLOT(parse_kernel()));
-	connect(parse_kernelAct, SIGNAL(activated()), this, SLOT(open_interfaces_kernel_txt()));
-	connect(parse_kernelAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	parse_servicesAct = new QAction(tr("Parse &Services"), 0, this);
-	parse_servicesAct->setStatusTip(tr("Parse .if files in services layer"));
-	connect(parse_servicesAct, SIGNAL(activated()), parse4, SLOT(parse_services()));
-	connect(parse_servicesAct, SIGNAL(activated()), this, SLOT(open_interfaces_services_txt()));
-	connect(parse_servicesAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	parse_systemAct = new QAction(tr("Parse S&ystem"), 0, this);
-	parse_systemAct->setStatusTip(tr("Parse .if files in system layer"));
-	connect(parse_systemAct, SIGNAL(activated()), parse5, SLOT(parse_system()));
-	connect(parse_systemAct, SIGNAL(activated()), this, SLOT(open_interfaces_system_txt()));
-	connect(parse_systemAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	obj_perm_setsAct = new QAction(tr("&Obj perm sets"), 0, this);
-	obj_perm_setsAct->setStatusTip(tr("Parse obj_perm_sets file"));
-	connect(obj_perm_setsAct, SIGNAL(activated()), parse6, SLOT(obj_perm_sets()));
-	connect(obj_perm_setsAct, SIGNAL(activated()), this, SLOT(open_obj_perm_sets_prepare_txt()));
-	connect(obj_perm_setsAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	ipc_patternsAct = new QAction(tr("&Ipc patterns"), 0, this);
-	ipc_patternsAct->setStatusTip(tr("Parse ipc patterns file"));
-	connect(ipc_patternsAct, SIGNAL(activated()), parse6, SLOT(ipc_patterns()));
-	connect(ipc_patternsAct, SIGNAL(activated()), this, SLOT(open_ipc_patterns_prepare_txt()));
-	connect(ipc_patternsAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	misc_patternsAct = new QAction(tr("&Misc patterns"), 0, this);
-	misc_patternsAct->setStatusTip(tr("Parse misc patterns file"));
-	connect(misc_patternsAct, SIGNAL(activated()), parse6, SLOT(misc_patterns()));
-	connect(misc_patternsAct, SIGNAL(activated()), this, SLOT(open_misc_patterns_prepare_txt()));
-	connect(misc_patternsAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	break_adminAct = new QAction(tr("Break &Admin"), 0, this);
-	break_adminAct->setStatusTip(tr("Break .if files in admin layer"));
-	connect(break_adminAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(break_adminAct, SIGNAL(activated()), parse9, SLOT(break_admin()));
-	connect(break_adminAct, SIGNAL(activated()), this, SLOT(open_interfaces_admin_broken_up_txt()));
-	connect(break_adminAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	break_appsAct = new QAction(tr("Break A&pps"), 0, this);
-	break_appsAct->setStatusTip(tr("Break .if files in apps layer"));
-	connect(break_appsAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(break_appsAct, SIGNAL(activated()), parse10, SLOT(break_apps()));
-	connect(break_appsAct, SIGNAL(activated()), this, SLOT(open_interfaces_apps_broken_up_txt()));
-	connect(break_appsAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	break_kernelAct = new QAction(tr("Break &Kernel"), 0, this);
-	break_kernelAct->setStatusTip(tr("Break .if files in kernel layer"));
-	connect(break_kernelAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(break_kernelAct, SIGNAL(activated()), parse11, SLOT(break_kernel()));
-	connect(break_kernelAct, SIGNAL(activated()), this, SLOT(open_interfaces_kernel_broken_up_txt()));
-	connect(break_kernelAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	break_servicesAct = new QAction(tr("Break &Services"), 0, this);
-	break_servicesAct->setStatusTip(tr("Break .if files in services layer"));
-	connect(break_servicesAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(break_servicesAct, SIGNAL(activated()), parse12, SLOT(break_services()));
-	connect(break_servicesAct, SIGNAL(activated()), this, SLOT(open_interfaces_services_broken_up_txt()));
-	connect(break_servicesAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	break_systemAct = new QAction(tr("Break S&ystem"), 0, this);
-	break_systemAct->setStatusTip(tr("Break .if files in system layer"));
-	connect(break_systemAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(break_systemAct, SIGNAL(activated()), parse13, SLOT(break_system()));
-	connect(break_systemAct, SIGNAL(activated()), this, SLOT(open_interfaces_system_broken_up_txt()));
-	connect(break_systemAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	selpaw_adminAct = new QAction(tr("Selpaw &Admin"), 0, this);
-	selpaw_adminAct->setStatusTip(tr("parse .if files into .csv file in admin layer"));
-	connect(selpaw_adminAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(selpaw_adminAct, SIGNAL(activated()), parse14, SLOT(selpaw_admin()));
-	connect(selpaw_adminAct, SIGNAL(activated()), this, SLOT(open_selpaw_admin_txt()));
-	connect(selpaw_adminAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	selpaw_appsAct = new QAction(tr("Selpaw A&pps"), 0, this);
-	selpaw_appsAct->setStatusTip(tr("parse .if files into .csv file in apps layer"));
-	connect(selpaw_appsAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(selpaw_appsAct, SIGNAL(activated()), parse14, SLOT(selpaw_apps()));
-	connect(selpaw_appsAct, SIGNAL(activated()), this, SLOT(open_selpaw_apps_txt()));
-	connect(selpaw_appsAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	selpaw_kernelAct = new QAction(tr("Selpaw &Kernel"), 0, this);
-	selpaw_kernelAct->setStatusTip(tr("parse .if files into .csv file in kernel layer"));
-	connect(selpaw_kernelAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(selpaw_kernelAct, SIGNAL(activated()), parse14, SLOT(selpaw_kernel()));
-	connect(selpaw_kernelAct, SIGNAL(activated()), this, SLOT(open_selpaw_kernel_txt()));
-	connect(selpaw_kernelAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	selpaw_servicesAct = new QAction(tr("Selpaw &Services"), 0, this);
-	selpaw_servicesAct->setStatusTip(tr("parse .if files into .csv file in services layer"));
-	connect(selpaw_servicesAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(selpaw_servicesAct, SIGNAL(activated()), parse14, SLOT(selpaw_services()));
-	connect(selpaw_servicesAct, SIGNAL(activated()), this, SLOT(open_selpaw_services_txt()));
-	connect(selpaw_servicesAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	selpaw_systemAct = new QAction(tr("Selpaw S&ystem"), 0, this);
-	selpaw_systemAct->setStatusTip(tr("parse .if files into .csv file in system layer"));
-	connect(selpaw_systemAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(selpaw_systemAct, SIGNAL(activated()), parse14, SLOT(selpaw_system()));
-	connect(selpaw_systemAct, SIGNAL(activated()), this, SLOT(open_selpaw_system_txt()));
-	connect(selpaw_systemAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	selpaw_interface_rawAct = new QAction(tr("Selpaw_interface_&raw.csv"), 0, this);
-	selpaw_interface_rawAct->setStatusTip(tr("Make selpaw_interface_raw.csv"));
-	connect(selpaw_interface_rawAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(selpaw_interface_rawAct, SIGNAL(activated()), selpaw1, SLOT(make_refine_selpaw()));
-	connect(selpaw_interface_rawAct, SIGNAL(activated()), this, SLOT(open_selpaw_interface_raw_csv()));
-	connect(selpaw_interface_rawAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	selpaw_eliminated_interfacesAct = new QAction(tr("Selpaw_&eliminated_interfaces.csv"), 0, this);
-	selpaw_eliminated_interfacesAct->setStatusTip(tr("Make selpaw_eliminated_interfaces.csv"));
-	connect(selpaw_eliminated_interfacesAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(selpaw_eliminated_interfacesAct, SIGNAL(activated()), selpawadjust1, SLOT(adjust_selpaw_ready()));
-	connect(selpaw_eliminated_interfacesAct, SIGNAL(activated()), this, SLOT(open_selpaw_eliminated_interfaces_csv()));
-	connect(selpaw_eliminated_interfacesAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	selpaw_interface_readyAct = new QAction(tr("Selpaw_interface_rea&dy.csv"), 0, this);
-	selpaw_interface_readyAct->setStatusTip(tr("Make selpaw_interface_ready.csv"));
-	connect(selpaw_interface_readyAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(selpaw_interface_readyAct, SIGNAL(activated()), selpawadjust1, SLOT(adjust_selpaw()));
-	connect(selpaw_interface_readyAct, SIGNAL(activated()), this, SLOT(open_selpaw_interface_ready_csv()));
-	connect(selpaw_interface_readyAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	selpaw_interface_csvAct = new QAction(tr("Selpaw_&interface.csv"), 0, this);
-	selpaw_interface_csvAct->setStatusTip(tr("Make selpaw_interface.csv"));
-	connect(selpaw_interface_csvAct, SIGNAL(activated()), this, SLOT(notice()));
-	connect(selpaw_interface_csvAct, SIGNAL(activated()), selpawadjust1, SLOT(refine_selpaw()));
-	connect(selpaw_interface_csvAct, SIGNAL(activated()), this, SLOT(open_selpaw_interface_csv()));
-	connect(selpaw_interface_csvAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+	breakteAct = new QAction(tr("Breake &te"), 0, this);
+	breakteAct->setStatusTip(tr("Break .te files"));
+	//connect(breakteAct, SIGNAL(activated()), breakte, SLOT(break_te()));
+	connect(breakteAct, SIGNAL(activated()), this, SLOT(break_te()));
+	connect(breakteAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
 	howtouseAct = new QAction(tr("&How to use"), 0, this);
 	howtouseAct->setStatusTip(tr("Show the application's How to use box"));
@@ -526,36 +366,8 @@ void MainWindow::createMenus()
 	aboutQtAct->addTo(helpMenu);
 
 	//newly added-2:add actino to menu
-	parselinesMenu = new QPopupMenu(this);
-
-	parse_adminAct->addTo(parselinesMenu);
-	parse_appsAct->addTo(parselinesMenu);
-	parse_kernelAct->addTo(parselinesMenu);
-	parse_servicesAct->addTo(parselinesMenu);
-	parse_systemAct->addTo(parselinesMenu);
-	obj_perm_setsAct->addTo(parselinesMenu);
-	ipc_patternsAct->addTo(parselinesMenu);
-	misc_patternsAct->addTo(parselinesMenu);
-	break_adminAct->addTo(parselinesMenu);
-	break_appsAct->addTo(parselinesMenu);
-	break_kernelAct->addTo(parselinesMenu);
-	break_servicesAct->addTo(parselinesMenu);
-	break_systemAct->addTo(parselinesMenu);
-
-	selpawMenu = new QPopupMenu(this);
-
-	selpaw_adminAct->addTo(selpawMenu);
-	selpaw_appsAct->addTo(selpawMenu);
-	selpaw_kernelAct->addTo(selpawMenu);
-	selpaw_servicesAct->addTo(selpawMenu);
-	selpaw_systemAct->addTo(selpawMenu);
-
-	refineMenu = new QPopupMenu(this);
-
-	selpaw_interface_rawAct->addTo(refineMenu);
-	selpaw_eliminated_interfacesAct->addTo(refineMenu);
-	selpaw_interface_readyAct->addTo(refineMenu);
-	selpaw_interface_csvAct->addTo(refineMenu);
+	breakteMenu = new QPopupMenu(this);
+	breakteAct->addTo(breakteMenu);
 
 	//newly added
 	auditMenu = new QPopupMenu(this);
@@ -605,9 +417,7 @@ void MainWindow::createMenus()
 	menuBar()->insertItem(tr("&Semanage"), semanageMenu);
 
 	menuBar()->insertSeparator();
-	menuBar()->insertItem(tr("Parse&Lines"), parselinesMenu);
-	menuBar()->insertItem(tr("Selpa&w"), selpawMenu);
-	menuBar()->insertItem(tr("&Refine"), refineMenu);
+	menuBar()->insertItem(tr("Break .&te"), breakteMenu);
 
 	menuBar()->insertSeparator();
 	menuBar()->insertItem(tr("Re&label"), relabelMenu);
@@ -708,185 +518,17 @@ void MainWindow::open()
 	else
 	editor->close();
 }
-
 //4:newly added
-void MainWindow::open_interfaces_admin_txt()
+/*
+void MainWindow::open_break_te_raw()
 {
 	Editor *editor = createEditor();
-	if (editor->openFile("/root/segatex/interfaces_admin.txt"))
+	if (editor->openFile("/root/segatex/acct.te_raw"))
 	editor->show();
 	else
 	editor->close();
 }
-void MainWindow::open_interfaces_apps_txt()
-{
-	Editor *editor = createEditor();
-	if (editor->openFile("/root/segatex/interfaces_apps.txt"))
-	editor->show();
-	else
-	editor->close();
-}
-void MainWindow::open_interfaces_kernel_txt()
-{
-	Editor *editor = createEditor();
-	if (editor->openFile("/root/segatex/interfaces_kernel.txt"))
-	editor->show();
-	else
-	editor->close();
-}
-void MainWindow::open_interfaces_services_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/interfaces_services.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_interfaces_system_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/interfaces_system.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_obj_perm_sets_prepare_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/obj_perm_sets_prepare.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_ipc_patterns_prepare_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/ipc_patterns_prepare.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_misc_patterns_prepare_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/misc_patterns_prepare.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_interfaces_admin_broken_up_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/interfaces_admin_broken_up.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_interfaces_apps_broken_up_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/interfaces_apps_broken_up.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_interfaces_kernel_broken_up_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/interfaces_kernel_broken_up.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_interfaces_services_broken_up_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/interfaces_services_broken_up.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_interfaces_system_broken_up_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/interfaces_system_broken_up.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_selpaw_admin_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/selpaw_admin.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_selpaw_apps_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/selpaw_apps.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_selpaw_kernel_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/selpaw_kernel.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_selpaw_services_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/selpaw_services.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_selpaw_system_txt()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/selpaw_system.txt"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_selpaw_interface_raw_csv()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/selpaw_interface_raw.csv"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_selpaw_eliminated_interfaces_csv()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/selpaw_eliminated_interfaces.csv"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_selpaw_interface_ready_csv()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/selpaw_interface_ready.csv"))
-        editor->show();
-    else
-        editor->close();
-}
-void MainWindow::open_selpaw_interface_csv()
-{
-    Editor *editor = createEditor();
-    if (editor->openFile("/root/segatex/selpaw_interface.csv"))
-        editor->show();
-    else
-        editor->close();
-}
-
+*/
 
 void MainWindow::openFile(const QString &fileName)
 {
@@ -953,7 +595,7 @@ void MainWindow::notice()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-6.60</h2>"
+		tr("<h2>segatex-6.80</h2>"
 		"<p>Copyright &copy; 2007-2008"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex is a SELinux tool"
@@ -983,16 +625,8 @@ void MainWindow::howtouse()
 		" You can add/delete Linux user."
 		" You can ftp download."
 		"<p><font color=\"blue\">[segatex_editor]</font>"
-		"<p>Push Parselines,Selpaw,Refine"
-		" one by one orderly."
-		"<p>If you could get three selpaw files,"
-		"i.e."
-		"selpaw_interface.csv,"
-		"selpaw_interface_types.csv,"
-		"selpaw_interface_summary.csv,"
-		" that is a success."
-		"<p>Break kernel may take 30 minutes, and"
-		" Refine selpaw takes 10 minutes;)</p>"));
+		"<p>Push break .te"
+		""));
 }
 
 
@@ -1099,6 +733,15 @@ void MainWindow::enforcing()
 	segatex_apply->setActiveWindow();
 }
 //newly added
+void MainWindow::break_te()
+{
+	if(!breakte_o) {
+		breakte_o = new BreakTe(this);
+	}
+	breakte_o->show();
+	breakte_o->raise();
+	breakte_o->setActiveWindow();
+}
 
 void MainWindow::yum_selinux()
 {
