@@ -32,6 +32,8 @@ class QSplitter;
 class QTextEdit;
 class QPushButton;
 class Editor;
+class BreakTe;
+/*
 class ParseLines;
 class ParseLinesAdmin;
 class ParseLinesApps;
@@ -42,6 +44,7 @@ class ParseLinesMisc;
 class ParseLinesSelpaw;
 class Selpaw;
 class SelpawAdjust;
+*/
 class SegatexState;
 class SegatexApply;
 class SegatexSetenforce;
@@ -83,28 +86,8 @@ private slots:
     void open();
 
     //newly added
-    void open_interfaces_admin_txt();
-    void open_interfaces_apps_txt();
-    void open_interfaces_kernel_txt();
-    void open_interfaces_services_txt();
-    void open_interfaces_system_txt();
-    void open_obj_perm_sets_prepare_txt();
-    void open_ipc_patterns_prepare_txt();
-    void open_misc_patterns_prepare_txt();
-    void open_interfaces_admin_broken_up_txt();
-    void open_interfaces_apps_broken_up_txt();
-    void open_interfaces_kernel_broken_up_txt();
-    void open_interfaces_services_broken_up_txt();
-    void open_interfaces_system_broken_up_txt();
-    void open_selpaw_admin_txt();
-    void open_selpaw_apps_txt();
-    void open_selpaw_kernel_txt();
-    void open_selpaw_services_txt();
-    void open_selpaw_system_txt();
-    void open_selpaw_interface_raw_csv();
-    void open_selpaw_eliminated_interfaces_csv();
-    void open_selpaw_interface_ready_csv();
-    void open_selpaw_interface_csv();
+    //void open_break_te_raw();
+    void break_te();
     void howtouse();
     void enforcing();
     void yum_selinux();
@@ -165,27 +148,15 @@ private:
     QString selinux_policy;
     QString enabled_or_not_str;
     QString getenforce_str;
-    
-    ParseLines *parse1;
-    ParseLines *parse2;
-    ParseLines *parse3;
-    ParseLines *parse4;
-    ParseLines *parse5;
-    ParseLines *parse6;
-    ParseLines *parse9;
-    ParseLines *parse10;
-    ParseLines *parse11;
-    ParseLines *parse12;    
-    ParseLines *parse13;        
-    ParseLines *parse14;
-    Selpaw *selpaw1;
-    SelpawAdjust *selpawadjust1;
+
+    BreakTe *breakte;
     SegatexState *segatex_state;
     SegatexApply *segatex_apply;
     SegatexSetenforce *segatex_apply_for_state;
     SegatexYum *selinux_yum;
     SegatexYumProcess *selinux_yum_process;
     SegatexAudit2allow *selinux_audit2allow;
+    BreakTe *breakte_o;
     SegatexCore *segatex_core_o;
     SemoduleCoreProcess *semodule_core_process_o;
     SemanageCoreProcess *semanage_core_process_o;
@@ -208,9 +179,7 @@ private:
     QPopupMenu *windowsMenu;
     QPopupMenu *helpMenu;
     //newly added
-    QPopupMenu *parselinesMenu;
-    QPopupMenu *selpawMenu;
-    QPopupMenu *refineMenu;
+    QPopupMenu *breakteMenu;
     QPopupMenu *auditMenu;
     QPopupMenu *policyMenu;
     QPopupMenu *manageMenu;
@@ -239,28 +208,7 @@ private:
     QAction *aboutAct;
     QAction *aboutQtAct;
     //newly added
-    QAction *parse_adminAct;
-    QAction *parse_appsAct;
-    QAction *parse_kernelAct;
-    QAction *parse_servicesAct;
-    QAction *parse_systemAct;
-    QAction *obj_perm_setsAct;
-    QAction *ipc_patternsAct;
-    QAction *misc_patternsAct;
-    QAction *break_adminAct;
-    QAction *break_appsAct;
-    QAction *break_kernelAct;
-    QAction *break_servicesAct;
-    QAction *break_systemAct;
-    QAction *selpaw_adminAct;
-    QAction *selpaw_appsAct;
-    QAction *selpaw_kernelAct;
-    QAction *selpaw_servicesAct;
-    QAction *selpaw_systemAct;
-    QAction *selpaw_interface_rawAct;
-    QAction *selpaw_eliminated_interfacesAct;
-    QAction *selpaw_interface_readyAct;
-    QAction *selpaw_interface_csvAct;
+    QAction *breakteAct;
     QAction *howtouseAct;
     QAction *enforcingAct;
     QAction *check_selinuxAct;
