@@ -26,10 +26,10 @@
 #include <qradiobutton.h>
 #include <qtextedit.h>
 #include <qlabel.h>
+#include <qcheckbox.h>
 
 
 class QLayout;
-class QCheckBox;
 class QTextEdit;
 class QLineEdit;
 class QPushButton;
